@@ -2472,7 +2472,7 @@ intptr_t PR2_GameSystemCalls(intptr_t *args) {
 
 		localcmd (string)
 		================= */
-		Cbuf_AddText(VMA(1));
+		Cbuf_AddTextEx(&cbuf_server, VMA(1));
 		return 0;
 	case G_CVAR:
 		return PASSFLOAT(Cvar_Value(VMA(1)));
