@@ -679,6 +679,22 @@ static void SVC_LastScores (void)
 	SV_EndRedirect ();
 }
 
+/*
+===================
+SVC_LastStats
+===================
+*/
+void SV_LastStats_f (void);
+static void SVC_LastStats (void)
+{
+	if(!(int)sv_allowlastscores.value)
+		return;
+
+	SV_BeginRedirect (RD_PACKET);
+	SV_LastStats_f ();
+	SV_EndRedirect ();
+}
+
 /*
 ===================
 SVC_DemoList
@@ -1893,6 +1909,8 @@ static void SV_ConnectionlessPacket (void)
 		SVC_GetChallenge ();
 	else if (!strcmp(c,"lastscores"))
 		SVC_LastScores ();
+	else if (!strcmp(c,"laststats"))
+		SVC_LastStats ();
 	else if (!strcmp(c,"dlist"))
 		SVC_DemoList ();
 	else if (!strcmp(c,"dlistr"))
@@ -3327,7 +3345,7 @@ void SV_InitLocal (void)
 	extern  cvar_t  pm_rampjump;
 	extern	cvar_t	pm_slidefix;
 	extern	cvar_t	pm_ktjump;
-	//extern	cvar_t	pm_bunnyspeedcap;
+	extern	cvar_t	pm_bunnyspeedcap;
 
 	// qws = QuakeWorld Server information
 	static cvar_t qws_name = { "qws_name", SERVER_NAME, CVAR_ROM };
@@ -3432,7 +3450,7 @@ void SV_InitLocal (void)
 	Cvar_Register (&sv_antilag_no_pred);
 	Cvar_Register (&sv_antilag_projectiles);
 
-	//Cvar_Register (&pm_bunnyspeedcap);
+	Cvar_Register (&pm_bunnyspeedcap);
 	Cvar_Register (&pm_ktjump);
 	Cvar_Register (&pm_slidefix);
 	Cvar_Register (&pm_pground);
@@ -3485,7 +3503,9 @@ void SV_InitLocal (void)
 #endif
 
 	Cvar_Register (&sv_extlimits);
+#ifdef MVD_PEXT1_SERVERSIDEWEAPON
 	Cvar_Register (&sv_pext_mvdsv_serversideweapon);
+#endif
 
 	Cvar_Register (&sv_reliable_sound);
 
